Skip to contents

Describe multivariate time series with tables and ggplots. mtsdesc provides commonly needed utilities when working with a set of time series, i.e. multi-panel plots and multi-column summary- and testing-tables. The package also has methods to work with residuals of fitter values of multivariate time series models.

Author

Maintainer: Ricardo Semião ricardo.semiao@outlook.com